@@ -8,7 +8,7 @@ has 'brush' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Brush',
     default => sub {
-        Graphics::Primitive::Brush->new;
+        Graphics::Primitive::Brush->new(width => 1);
     }
 );
 has 'color' => (
@@ -20,19 +20,19 @@ has 'color' => (
         );
     }
 );
+has 'inside_color' => (
+    is => 'rw',
+    isa => 'Graphics::Color',
+    default => sub {
+        Graphics::Color::RGB->new(
+            red => 0, green => 0, blue => 0, alpha => 1
+        );
+    }
+);
 has 'key' => ( is => 'rw', isa => 'Num' );
 has 'key2' => ( is => 'rw', isa => 'Num' );
 has 'value' => ( is => 'rw', isa => 'Num' );
 has 'value2' => ( is => 'rw', isa => 'Num' );
-has 'inside_color' => (
-    is => 'rw',
-    isa => 'Graphics::Color',
-    default => sub {
-        Graphics::Color::RGB->new(
-            red => 0, green => 0, blue => 0, alpha => 1
-        );
-    }
-);
 
 __PACKAGE__->meta->make_immutable;
 
